.. currentmodule:: orangewidget.workflow.drophandler

:mod:`orangewidget.workflow.drophandler`
----------------------------------------

.. automodule:: orangewidget.workflow.drophandler

.. autoclass:: OWNodeFromMimeDataDropHandler
   :show-inheritance:
   :members:

.. autoclass:: SingleUrlDropHandler
   :show-inheritance:
   :members:

.. autoclass:: UrlsDropHandler
   :show-inheritance:
   :members:

.. autoclass:: SingleFileDropHandler
   :show-inheritance:
   :members:

.. autoclass:: FilesDropHandler
   :show-inheritance:
   :members:
